@@ -17,11 +17,11 @@ class AnnofabCliException(Exception):
 
 class AuthenticationError(AnnofabCliException):
     """
-    AnnoFabの認証エラー
+    Annofabの認証エラー
     """
 
-    def __init__(self, loing_user_id: str):
-        msg = f"AnnoFabにログインできませんでした。User ID: {loing_user_id}"
+    def __init__(self, loing_user_id: str) -> None:
+        msg = f"Annofabにログインできませんでした。User ID: {loing_user_id}"
         super().__init__(msg)
 
 
@@ -43,10 +43,10 @@ class AuthorizationError(AnnofabCliException):
 
 class ProjectAuthorizationError(AuthorizationError):
     """
-    AnnoFabプロジェクトに関する認可エラー
+    Annofabプロジェクトに関する認可エラー
     """
 
-    def __init__(self, project_title: str, roles: List[ProjectMemberRole]):
+    def __init__(self, project_title: str, roles: List[ProjectMemberRole]) -> None:
         role_values = [e.value for e in roles]
         msg = f"プロジェクト: {project_title} に、ロール: {role_values} のいずれかが付与されていません。"
         super().__init__(msg)
@@ -54,10 +54,10 @@ class ProjectAuthorizationError(AuthorizationError):
 
 class OrganizationAuthorizationError(AuthorizationError):
     """
-    AnnoFab組織に関する認可エラー
+    Annofab組織に関する認可エラー
     """
 
-    def __init__(self, organization_name: str, roles: List[OrganizationMemberRole]):
+    def __init__(self, organization_name: str, roles: List[OrganizationMemberRole]) -> None:
         role_values = [e.value for e in roles]
         msg = f"組織: {organization_name} に、ロール: {role_values} のいずれかが付与されていません。"
         super().__init__(msg)
