@@ -6,22 +6,21 @@ from typing import Optional
 
 import annofabapi
 import pyquery
-from annofabapi.models import ProjectMemberRole
 
 import annofabcli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
+from annofabcli.common.facade import AnnofabApiFacade
 
 logger = logging.getLogger(__name__)
 
 
 class DownloadInstructionMain:
-    def __init__(self, service: annofabapi.Resource):
+    def __init__(self, service: annofabapi.Resource) -> None:
         self.service = service
         self.facade = AnnofabApiFacade(service)
 
@@ -113,7 +112,7 @@ class DownloadInstructionMain:
             )
 
         output_html = output_dir / "index.html"
-        output_html.write_text(str_instruction_html)
+        output_html.write_text(str_instruction_html, encoding="utf-8")
         logger.debug(f"{output_html} をダウンロードしました。")
 
 
@@ -129,11 +128,11 @@ class DownloadInstruction(AbstractCommandLineInterface):
         history = histories[before]
         return history["history_id"]
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
 
         project_id = args.project_id
-        super().validate_project(project_id, project_member_roles=[ProjectMemberRole.OWNER])
+        super().validate_project(project_id)
 
         if args.before is not None:
             history_id = self.get_history_id_from_before_index(args.project_id, args.before)
@@ -152,13 +151,13 @@ class DownloadInstruction(AbstractCommandLineInterface):
         )
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     DownloadInstruction(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     argument_parser.add_project_id()
@@ -195,11 +194,10 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "download"
     subcommand_help = "作業ガイドをダウンロードします。"
     description = "作業ガイドをダウンロードします。HTMLファイルにはbodyタグの内部が記載されています。"
-    epilog = "オーナロールを持つユーザで実行してください。"
-    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
+    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description)
     parse_args(parser)
     return parser
