@@ -14,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 
 class ListTaskCreationHistoryMain:
-    def __init__(self, service: annofabapi.Resource):
+    def __init__(self, service: annofabapi.Resource) -> None:
         self.service = service
         self.facade = AnnofabApiFacade(service)
 
@@ -37,7 +37,7 @@ class ListTaskCreationHistoryMain:
 
 
 class ListTaskCreationHistory(AbstractCommandLineInterface):
-    def main(self):
+    def main(self) -> None:
         args = self.args
         main_obj = ListTaskCreationHistoryMain(self.service)
         data_list = main_obj.get_data_list(args.project_id)
@@ -50,13 +50,13 @@ class ListTaskCreationHistory(AbstractCommandLineInterface):
             self.print_according_to_format(data_list)
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     ListTaskCreationHistory(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     argument_parser.add_project_id()
@@ -71,7 +71,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "list_task_creation_history"
     subcommand_help = "タスクの作成履歴一覧を出力します。"
     description = "タスクの作成履歴一覧を出力します。"
