@@ -1,29 +1,29 @@
 import argparse
+from typing import Optional
 
 import annofabcli
 import annofabcli.common.cli
 import annofabcli.project_member.change_project_members
 import annofabcli.project_member.copy_project_members
-import annofabcli.project_member.delete_users
-import annofabcli.project_member.invite_users
+import annofabcli.project_member.drop_project_members
+import annofabcli.project_member.invite_project_members
 import annofabcli.project_member.list_users
 import annofabcli.project_member.put_project_members
 
 
-def parse_args(parser: argparse.ArgumentParser):
-
+def parse_args(parser: argparse.ArgumentParser) -> None:
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
     annofabcli.project_member.change_project_members.add_parser(subparsers)
     annofabcli.project_member.copy_project_members.add_parser(subparsers)
-    annofabcli.project_member.delete_users.add_parser(subparsers)
-    annofabcli.project_member.invite_users.add_parser(subparsers)
+    annofabcli.project_member.drop_project_members.add_parser(subparsers)
+    annofabcli.project_member.invite_project_members.add_parser(subparsers)
     annofabcli.project_member.list_users.add_parser(subparsers)
     annofabcli.project_member.put_project_members.add_parser(subparsers)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "project_member"
     subcommand_help = "プロジェクトメンバ関係のサブコマンド"
     description = "プロジェクトメンバ関係のサブコマンド"
@@ -32,3 +32,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
         subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
     )
     parse_args(parser)
+    return parser
