@@ -12,7 +12,6 @@ from annofabapi.models import ProjectMemberRole
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
@@ -20,6 +19,7 @@ from annofabcli.common.cli import (
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
+from annofabcli.common.facade import AnnofabApiFacade
 
 logger = logging.getLogger(__name__)
 
@@ -33,7 +33,7 @@ class UpdateMetadataOfTaskMain(AbstractCommandLineWithConfirmInterface):
         is_overwrite_metadata: bool,
         parallelism: Optional[int] = None,
         all_yes: bool = False,
-    ):
+    ) -> None:
         self.service = service
         self.is_overwrite_metadata = is_overwrite_metadata
         self.parallelism = parallelism
@@ -53,7 +53,6 @@ class UpdateMetadataOfTaskMain(AbstractCommandLineWithConfirmInterface):
         task_index: Optional[int] = None,
     ) -> bool:
         logging_prefix = f"{task_index+1} 件目" if task_index is not None else ""
-
         task = self.service.wrapper.get_task_or_none(project_id, task_id)
         if task is None:
             logger.warning(f"{logging_prefix} タスク '{task_id}' は存在しないのでスキップします。")
@@ -74,14 +73,18 @@ class UpdateMetadataOfTaskMain(AbstractCommandLineWithConfirmInterface):
         logger.debug(f"{logging_prefix} タスク '{task_id}' のメタデータを更新しました。")
         return True
 
-    def set_metadata_to_task_wrapper(self, tpl: tuple[int, str], project_id: str, metadata: Dict[str, Any]):
+    def set_metadata_to_task_wrapper(self, tpl: tuple[int, str], project_id: str, metadata: Dict[str, Any]) -> bool:
         task_index, task_id = tpl
-        return self.set_metadata_to_task(
-            project_id,
-            task_id,
-            metadata=metadata,
-            task_index=task_index,
-        )
+        try:
+            return self.set_metadata_to_task(
+                project_id,
+                task_id,
+                metadata=metadata,
+                task_index=task_index,
+            )
+        except Exception:
+            logger.warning(f"タスク'{task_id}'のメタデータの更新に失敗しました。", exc_info=True)
+            return False
 
     def update_metadata_of_task(
         self,
@@ -111,14 +114,18 @@ class UpdateMetadataOfTaskMain(AbstractCommandLineWithConfirmInterface):
             else:
                 # 逐次処理
                 for task_index, task_id in enumerate(task_ids):
-                    result = self.set_metadata_to_task(
-                        project_id,
-                        task_id,
-                        metadata=metadata,
-                        task_index=task_index,
-                    )
-                    if result:
-                        success_count += 1
+                    try:
+                        result = self.set_metadata_to_task(
+                            project_id,
+                            task_id,
+                            metadata=metadata,
+                            task_index=task_index,
+                        )
+                        if result:
+                            success_count += 1
+                    except Exception:
+                        logger.warning(f"タスク'{task_id}'のメタデータの更新に失敗しました。", exc_info=True)
+                        continue
 
             logger.info(f"{success_count} / {len(task_ids)} 件のタスクのmetadataを変更しました。")
 
@@ -176,14 +183,14 @@ class UpdateMetadataOfTask(AbstractCommandLineInterface):
 
         if args.parallelism is not None and not args.yes:
             print(
-                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism' を指定するときは、必ず  ``--yes``  を指定してください。",
+                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism' を指定するときは、必ず  '--yes'  を指定してください。",
                 file=sys.stderr,
             )
             return False
 
         return True
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
 
         if not self.validate(args):
@@ -198,13 +205,13 @@ class UpdateMetadataOfTask(AbstractCommandLineInterface):
         main_obj.update_metadata_of_task(args.project_id, task_ids=task_id_list, metadata=metadata)
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     UpdateMetadataOfTask(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
     argument_parser.add_project_id()
     argument_parser.add_task_id(required=True)
@@ -230,7 +237,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "update_metadata"
     subcommand_help = "タスクのメタデータを更新します。"
     description = "タスクのメタデータを上書きして更新します。"
